<?php
// This program is free software; you can redistribute it and/or modify it   
// under the terms of the GNU General Public License as published by the     
// Free Software Foundation; either version 2 of the License, or (at your    
// option) any later version.                                                
// 
// File: schema.php

// For this page, we DONT want SQL debug on the screen (0 is shown on screen, 1 is hidden)
$silent = 0;

// Different DB's treat BIGINT/INT8, and FLOAT differently. Here we define them depending on the db.
$bigint_name = '';
if ($db_type=="mssql" || $db_type=="odbc_mssql" || $db_type=="ado_mssql")
{
    $bigint_name = 'BIGINT';
    $float_size = '';
}
elseif ($db_type=="postgres7")
{
    $bigint_name = 'INT8';
    $float_size = '';
}
elseif ($db_type=="mysql")
{
    $bigint_name = 'BIGINT';
    $float_size = '8.6';
}

function destroy_schema()
{
    global $dbtables;
    global $db;
    global $db_type;
    global $silent;
    global $served_page;

    $cumulative = 0; // Clears the db error counter

    // Delete all tables in the database
    echo "<b>Dropping all tables </b><br>";
    foreach ($dbtables as $table => $tablename)
    {
        echo "Dropping $table ";
        $throw_away = $db->Execute("SELECT * from $tablename");
        if ($throw_away)
        {
            $debug_query = $db->Execute("DROP TABLE $tablename");
            db_op_result($debug_query,__LINE__,__FILE__);
        }
        else
        {
            $cumulative = 1;
            echo "<font color=\"yellow\">- warning - no table present.</font><br>\n";
        }
    }

    $debug_query = '';
    if ($cumulative == 0)
    {
        echo "<b>All tables have been successfully dropped.</b><p>";
    }
    else
    {
        echo "<b><font color=\"yellow\">At least one warning or error occured during table drops.</font></b><p>\n";
    }
}

function drop_seq($db, $tabname, $seq_name)
{
    global $cumulative;

    echo "Dropping $seq_name: ";
    $second_part = "_" . $seq_name . "_seq";
    $first_length = 31 - strlen($second_part);
    $other_length = strlen($second_part) - 31;
    $first_part = substr( $tabname, 0, -($other_length));
    $sequence = $first_part . $second_part;

    $debug_query = $db->Execute("DROP SEQUENCE $sequence");
    db_op_result($debug_query,__LINE__,__FILE__);
}

function destroy_seq()
{
    global $db, $dbtables, $cumulative, $db_type;

    $cumulative = 0; // Clears the db error counter


    // Delete all sequences in the database
    echo "<b>Dropping all sequences </b><br>";

    drop_seq($db, $dbtables['logs'], 'log_id');
    drop_seq($db, $dbtables['adminnews'], 'an_id');
    drop_seq($db, $dbtables['autoroutes'], 'autoroute_id');
    drop_seq($db, $dbtables['bounty'], 'bounty_id');
    drop_seq($db, $dbtables['config_values'], 'id');
    drop_seq($db, $dbtables['detect'], 'det_id');
    drop_seq($db, $dbtables['dignitary'], 'dig_id');
    drop_seq($db, $dbtables['email_log'], 'log_id');
    drop_seq($db, $dbtables['ibank_accounts'], 'player_id');
    drop_seq($db, $dbtables['igb_transfers'], 'transfer_id');
    drop_seq($db, $dbtables['ip_bans'], 'ban_id');
    drop_seq($db, $dbtables['ip_log'], 'log_id');
//    drop_seq($db, $dbtables['kabal'], 'kabal_id');             // -- no clue why this causes an error
    drop_seq($db, $dbtables['languages'], 'id');
    drop_seq($db, $dbtables['links'], 'link_id');
    drop_seq($db, $dbtables['messages'], 'ID');
    drop_seq($db, $dbtables['movement_log'], 'event_id');
    drop_seq($db, $dbtables['news'], 'news_id');
    drop_seq($db, $dbtables['planet_log'], 'planetlog_id');
    drop_seq($db, $dbtables['planets'], 'planet_id');
    drop_seq($db, $dbtables['player_team_history'], 'history_id');
    drop_seq($db, $dbtables['players'], 'player_id');
    drop_seq($db, $dbtables['scan_log'], 'event_id');
    drop_seq($db, $dbtables['scheduler'], 'sched_id');
    drop_seq($db, $dbtables['sector_defence'], 'defence_id');
//    drop_seq($db, $dbtables['sessions'], 'SESSKEY');           // -- no clue why this causes an error
//    drop_seq($db, $dbtables['ship_types'], 'type_id');         // -- no clue why this causes an error
    drop_seq($db, $dbtables['ships'], 'ship_id');
    drop_seq($db, $dbtables['shoutbox'], 'sb_id');
    drop_seq($db, $dbtables['spies'], 'spy_id');
    drop_seq($db, $dbtables['teams'], 'id');
    drop_seq($db, $dbtables['traderoutes'], 'traderoute_id');
    drop_seq($db, $dbtables['universe'], 'sector_id');
    drop_seq($db, $dbtables['zones'], 'zone_id');
    drop_seq($db, $dbtables['probe'], 'probe_id');	
    drop_seq($db, $dbtables['message_block'], 'mb_id');	

    drop_seq($db, $dbtables['forums'], 'forum_id');	
    drop_seq($db, $dbtables['fplayers'], 'rec_id');	
    drop_seq($db, $dbtables['posts'], 'post_id_id');	
    drop_seq($db, $dbtables['posts_text'], 'post_id');	
    drop_seq($db, $dbtables['topics'], 'topic_id');	
    drop_seq($db, $dbtables['autotrades'], 'traderoute_id');	
    drop_seq($db, $dbtables['presets'], 'presets');	
    drop_seq($db, $dbtables['sector_notes'], 'sector_notes');	

    drop_seq($db, $dbtables['casino_forums'], 'forum_id');	
    drop_seq($db, $dbtables['casino_posts'], 'post_id_id');	
    drop_seq($db, $dbtables['casino_posts_text'], 'post_id');	
    drop_seq($db, $dbtables['casino_topics'], 'topic_id');	

    drop_seq($db, $dbtables['ship_mounts'], 'ship_mounts');	
    drop_seq($db, $dbtables['planet_research'], 'planet_research');	
    drop_seq($db, $dbtables['planet_research_built'], 'planet_research_built');	
    drop_seq($db, $dbtables['research_items'], 'research_items');	

    $debug_query = '';
    if ($cumulative == 0)
    {
        echo "<b>All sequences have been successfully dropped.</b><p>";
    }
    else
    {
        echo "<b><font color=\"yellow\">At least one error occured during sequence drops.</font></b><p>\n";
    }
}

function create_index($dict, $index_name, $simple_table_name, $table, $index1, $index2)
{
    global $db, $cumulative;
    echo "Creating table: $simple_table_name index: $index_name ";
    $sqlarray = $dict->CreateIndexSQL($index_name . "_" . $simple_table_name, $table, $index1, $index2);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
}

function create_schema()
{
    // If you add/remove a table, don't forget to update the
    // table name variables in the global_func file.

    global $maxlen_password;
    global $dbtables;
    global $db;
    global $db_mysql_type;
    global $default_prod_ore;
    global $default_prod_organics;
    global $default_prod_goods;
    global $default_prod_energy;
    global $default_prod_fighters;
    global $default_prod_torp;
    global $silent;
    global $served_page;
    global $bigint_name;
    global $db_type;
    global $float_size;

	if($db_type == "mysql" and $db_mysql_type == "InnoDB"){
		$taboptarray = array('mysql' => 'TYPE=InnoDB');
	}
	else
	{
		$taboptarray=false;
	}

    // Create database schema

    $cumulative = 0; // Clears the db error counter

    echo "<b>Creating tables </b><br>";

    // Logs must go first, to catch errors. Else, its all alphabetical order.

    // Start logs table
    echo "Creating table: logs ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('log_id',    'I',          '',     '',           'auto',  'primary'),
                      array('player_id', 'I',          '',     'default' => '0',     'notnull'),
                      array('type', 'I',          '',     'default' => '0',     'notnull'),
                      array('time',      'T',  '',     '',                   ''),
                      array('data',      'X',          '',  '',                   ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['logs'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'player_id',  'logs',  $dbtables['logs'],  'player_id',  'log_id');
    // End logs table

    // Start admin news table
    echo "Creating table: Admin News ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('an_id',     'I',  '',     '',  'auto',  'primary'),
                      array('an_text',    'X',  '',     '',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['adminnews'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End admin news table

    // Start of autoroute table
    echo "Creating table: autoroutes ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('autoroute_id',  'I',  '',   '',  'notnull',  'auto',  'primary'),
                      array('start_sector',   'I',  '',   'default' => '0',  'notnull'),
                      array('destination',   'I',  '',   'default' => '0',  'notnull'),
                      array('warp_list',     'X',  '',  '',  'notnull'),
                      array('player_id',     'I',  '',   'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['autoroutes'], $fldarray, $taboptarray);

    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'player_id',  'autoroutes',  $dbtables['autoroutes'],  'player_id',  'autoroute_id');

    // End of autoroutes table

    // Start of traderoutes table
    echo "Creating table: autotrades ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('traderoute_id',  'I',  '',   '',  'auto',     'primary'),
                      array('planet_id',      'I',  '',   'default' => '0',  'notnull'),
                      array('port_id_goods',        'I',  '',   'default' => '0',  'notnull'),
                      array('goods_price',        'I',  '',   'default' => '0',  'notnull'),
                      array('port_id_ore',        'I',  '',   'default' => '0',  'notnull'),
                      array('ore_price',        'I',  '',   'default' => '0',  'notnull'),
                      array('port_id_organics',        'I',  '',   'default' => '0',  'notnull'),
                      array('organics_price',        'I',  '',   'default' => '0',  'notnull'),
                      array('port_id_energy',        'I',  '',   'default' => '0',  'notnull'),
                      array('energy_price',        'I',  '',   'default' => '0',  'notnull'),
                      array('current_trade',        $bigint_name,  '',   'default' => '0',  'notnull'),
                      array('owner',          'I',  '',   'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['autotrades'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'owner',  'autotrades',  $dbtables['autotrades'],  'owner',  'traderoute_id');
    create_index($dict,  'planet_id',  'autotrades',  $dbtables['autotrades'],  'planet_id',  'traderoute_id');

    // End of autotrades table

    // Start bounty table
    echo "Creating table: bounty ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('bounty_id',  'I',           '',  '',  'auto',  'primary'),
                      array('amount',          'DECIMAL',  '32.0',                'default' => '0.0',  'notnull'),
                      array('bounty_on',  'I',           '',  'default' => '0',  'notnull'),
                      array('placed_by',  'I',           '',  'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['bounty'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'placed_by',  'bounty',  $dbtables['bounty'],  'placed_by',  'bounty_id');
    create_index($dict,  'bounty_on',  'bounty',  $dbtables['bounty'],  'bounty_on',  'bounty_id');
    // End bounty table

    // Start Config values table
    echo "Creating table: Config Values ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(        
                      array('id',     'I',  '',     '',  'auto',  'primary'),
                      array('name',   'C',  '30',   '',                ''),
                      array('value',  'C',  '250',  '',                ''),
                      array('description',    'X',  '',     '',  'notnull'),
                      array('section',  'C',  '100',  '',                ''),
                     );    

    $sqlarray = $dict->CreateTableSQL($dbtables['config_values'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End Config values table

    // Start detect table
    echo "Creating table: Detect ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('det_id',        $bigint_name,  '',     '',  'auto',  'primary'), 
                      array('owner_id',      'I',           '',     'default' => '0',  'notnull'),
                      array('det_type',      'I',           '',     'default' => '0',  'notnull'),            
                      array('det_time',      'T',   '',     '',                ''),
                      array('data',          'C',           '255',  '',                ''),
                      array('unique_value',  $bigint_name,  '',     '',                ''), 
                     );  

    $sqlarray = $dict->CreateTableSQL($dbtables['detect'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'owner_id',  'detect',  $dbtables['detect'],  'owner_id',  'det_id');
    // End detect table

    // Start debris table
    echo "Creating table: Debris ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('debris_id',       $bigint_name,  '',           '',       'auto',  'primary'),
                      array('debris_type',     'I',           '',           'default' => '0',       'notnull'),   
                      array('debris_data',    'C',           '50',         'default' => '',  'notnull'),    
                      array('sector_id',    'I',           '',           'default' => '0',       'notnull'),   
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['debris'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'debris_id',  'debris',  $dbtables['debris'],  'debris_id',  'debris_id');
    create_index($dict,  'sector_id',   'debris',  $dbtables['debris'],  'sector_id',   'debris_id');
    create_index($dict,  'debris_type',    'debris',  $dbtables['debris'],  'debris_type',    'debris_id');
    // End debris table

    // Start digitary table
    echo "Creating table: Dignitaries ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('dig_id',       $bigint_name,  '',           '',       'auto',  'primary'),
                      array('active',       'C',           '1',          'default' => 'N',       'notnull'),   
                      array('owner_id',     'I',           '',           'default' => '0',       'notnull'),   
                      array('planet_id',    'I',           '',           'default' => '0',       'notnull'),   
                      array('ship_id',      'I',           '',           'default' => '0',       'notnull'),   
                      array('job_id',       'I1',           '',           'default' => '0',       'notnull'),            
                      array('percent',  'DECIMAL',       $float_size,  'default' => '0',     'notnull'),   
                      array('active_date',      'T',   '',     '',                ''),
                      array('reactive_date',      'T',   '',     '',                ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['dignitary'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'planet_id',  'dignitary',  $dbtables['dignitary'],  'planet_id',  'dig_id');
    create_index($dict,  'owner_id',   'dignitary',  $dbtables['dignitary'],  'owner_id',   'dig_id');
    create_index($dict,  'ship_id',    'dignitary',  $dbtables['dignitary'],  'ship_id',    'dig_id');
    create_index($dict,  'active',    'dignitary',  $dbtables['dignitary'],  'active',    'dig_id');
    // End Dignitary table

    // Start email log table
    echo "Creating table: Email Log ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('log_id',     'I',  '',     '',  'auto',  'primary'),
                      array('sp_name',    'C',  '50',   'default' => '',   'notnull'),             
                      array('sp_IP',      'C',  '16',   'default' => '',   'notnull'),             
                      array('dp_name',    'C',  '50',   'default' => '',   'notnull'), 
                      array('e_subject',  'C',  '250',  'default' => '',   ''), 
                      array('e_status',   'C',  '1',    'default' => 'N',  'notnull'), 
                      array('e_type',     'I',  '',     'default' => '0',  'notnull'),
                      array('e_stamp',    'C',  '20',   'default' => '',   ''), 
                      array('e_response', 'C',  '250',  'default' => '',   ''), 
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['email_log'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End email log

    // Start ibank accounts table
    echo "Creating table: ibank accounts ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(   
                      array('player_id',  'I',           '',    '',    'auto',     'primary'),
                      array('balance',    $bigint_name,  '',    'default' => '0',    'notnull'),        
                      array('loan',       $bigint_name,  '',    'default' => '0',    'notnull'),        
                      array('loantime',   'T',   '',    '',                  ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['ibank_accounts'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'loantime',  'ibank_accounts',  $dbtables['ibank_accounts'],  'loantime',  'player_id');
    // End of ibank accounts table

    // Start ibank transfers table
    echo "Creating table: ibank transfers ";
    $dict = NewDataDictionary($db); 
// TODO - update the name of the table to ibank_transfers
    $fldarray = array(
                      array('transfer_id',  'I',          '',  '',  'auto',     'primary'),
                      array('source_id',    'I',          '',  'default' => '0',  'notnull'),
                      array('dest_id',      'I',          '',  'default' => '0',  'notnull'),
                      array('time',         'T',  '',  '',                ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['igb_transfers'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'source_id',  'igb_transfers',  $dbtables['igb_transfers'],  'source_id',  'transfer_id');
    create_index($dict,  'dest_id',  'igb_transfers',  $dbtables['igb_transfers'],  'dest_id',  'transfer_id');
    create_index($dict,  'time',  'igb_transfers',  $dbtables['igb_transfers'],  'time',  'transfer_id');
    // End of ibank accounts table

    // Start ip bans table
    echo "Creating table: ip bans ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('ban_id',    'I',  '',    '',  'auto',    'primary'),         
                      array('ban_mask',  'C',  '16',  '',                'notnull'),           
                      array('email',  'C',  '150',  '',                'notnull'),           
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['ip_bans'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End ip bans table

    // Start ip log table
    echo "Creating table: ip log ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('log_id',      'I',          '',    '',  'auto',  'primary'),
                      array('player_id',   'I',          '',    'default' => '0',  'notnull'),
                      array('ip_address',  'C',          '16',  'default' => '',   'notnull'),
                      array('time',        'T',  '',    '',                ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['ip_log'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'player_id',  'ip_log',  $dbtables['ip_log'],  'player_id',  'log_id');
    // End ip_log

    // Start kabal table
    echo "Creating table: kabal ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('kabal_id',    'C',  '40',  '',                'notnull',  'primary'),
                      array('active',      'C',  '1',   'default' => 'Y',  'notnull'),
                      array('aggression',  'I',  '',    'default' => '0',  'notnull'),             
                      array('orders',      'I',  '',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['kabal'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

    // End of kabal table

    // Start Languages table
    echo "Creating table: Languages ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('id',         'I',  '',    '',  'auto',  'primary'), 
                      array('name',       'C',  '30',  '',                ''), 
                      array('value',      'C',  '30',  '',                ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['languages'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End Languages table

    // Start of links table
    echo "Creating table: links ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('link_id',     'I',  '',  '',  'auto',  'primary'),
                      array('link_start',  'I',  '',  'default' => '0',  'notnull'),
                      array('link_dest',   'I',  '',  'default' => '0',  'notnull')
                     );
    $sqlarray = $dict->CreateTableSQL($dbtables['links'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray); 
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'link_start',  'links',  $dbtables['links'],  'link_start',  'link_id');
    create_index($dict,  'link_dest',   'links',  $dbtables['links'],  'link_dest',   'link_id');

    // End of links table

    // Start messaging table
    echo "Creating table: messages ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('ID',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('sender_id',  'I',  '',     'default' => '0',  'notnull'),
                      array('recp_id',    'I',  '',     'default' => '0',  'notnull'),
                      array('subject',    'C',  '250',  'default' => '',   'notnull'),
                      array('sent',       'C',  '19',   '',                ''),
                      array('message',    'X',  '',     '',                'notnull'), 
                      array('notified',   'C',  '1',    'default' => 'N',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['messages'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'recp_id',  'messages',  $dbtables['messages'],  'recp_id',  'ID');
    // End messaging table

    // Start movement log table
    echo "Creating table: movement log ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('event_id',      'I',          '',     '',     'auto',  'primary'),
                      array('ship_id',       'I',          '',     'default' => '0',     'notnull'),
                      array('player_id',     'I',          '',     'default' => '0',     ''),
                      array('source',        'I',          '',     'default' => '0',     ''),
                      array('destination',   'I',          '',     'default' => '0',     ''),
                      array('ship_class',    'I',          '',     'default' => '0',     ''),
                      array('error_factor',  'I',          '',     'default' => '0',     ''),
                      array('time',          'T',  '',     '',                   ''),
                      array('zone_id',  'I',          '',     'default' => '0',     ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['movement_log'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'ship_id',  'movement_log',  $dbtables['movement_log'],  'ship_id',  'event_id');
    create_index($dict,  'source',  'movement_log',  $dbtables['movement_log'],  'source',  'event_id');
    create_index($dict,  'zone_id',  'movement_log',  $dbtables['movement_log'],  'zone_id',  'event_id');
    create_index($dict,  'player_id',  'movement_log',  $dbtables['movement_log'],  'player_id',  'event_id');
    // End movement log table

    // Start news table
    echo "Creating table: news ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('news_id',    'I',          '',    '',  'auto',     'primary'),
                      array('data',       'C',          '90',  '',                'notnull'),
                      array('total',    'I',          '',    '0',                ''),
                      array('user_id',    'I',          '',    '',                ''),
                      array('date',       'T',  '',    '',                ''),
                      array('news_type',  'C',          '50',  '',                ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['news'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'date',  'news',  $dbtables['news'],  'date',  'news_id');
    // End of news table

    // Start planet log table
    echo "Creating table: planet log ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('planetlog_id',  'I',          '',    '',  'auto',  'primary'),
                      array('planet_id',     'I',          '',    'default' => '0',  ''),
                      array('player_id',     'I',          '',    'default' => '0',  'notnull'),
                      array('owner_id',      'I',          '',    'default' => '0',  'notnull'),
                      array('ip_address',    'C',          '16',  'default' => '0',  'notnull'),
                      array('action',        'I1',          '',    'default' => '0',  'notnull'),
                      array('time',          'T',  '',    '',                ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['planet_log'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'planet_id',  'planet_log',  $dbtables['planet_log'],  'planet_id',  'planetlog_id');
    create_index($dict,  'player_id',  'planet_log',  $dbtables['planet_log'],  'player_id',  'planetlog_id');
    create_index($dict,  'owner_id',  'planet_log',  $dbtables['planet_log'],  'owner_id',  'planetlog_id');
    create_index($dict,  'action',  'planet_log',  $dbtables['planet_log'],  'action',  'planetlog_id');
    create_index($dict,  'time',  'planet_log',  $dbtables['planet_log'],  'time',  'planetlog_id');
    // End planet_log

    // Start of planets table
    echo "Creating table: planets ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('planet_id',       'I',           '',    '',  'auto',     'primary'),
                      array('sector_id',       'I',           '',    'default' => '0',  'notnull'),
                      array('name',            'C',           '15',  'default' => '',   ''),
                      array('organics',        $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('ore',             $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('goods',           $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('energy'  ,        $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('colonists',       $bigint_name,  '',    'default' => '0',  'notnull'),      
                      array('credits',          'DECIMAL',  '24.0',                'default' => '0.0',  'notnull'),
                      array('max_credits',          'DECIMAL',  '24.0',                'default' => '0.0',  'notnull'),
                      array('computer',        'I1',           '',    'default' => '0',  'notnull'),
                      array('computer_normal',           'I1',           '',    'default' => '0',  'notnull'), 
                      array('computer_class',   'C',           '99',  'default' => 'Basic_Computer',   ''),
                      array('sensors',         'I1',           '',    'default' => '0',  'notnull'),
                      array('sensors_normal',            'I1',           '',    'default' => '0',  'notnull'),          
                      array('beams',           'I1',           '',    'default' => '0',  'notnull'),
                      array('beams_normal',              'I1',           '',    'default' => '0',  'notnull'), 
                      array('beam_class',   'C',           '99',  'default' => 'Basic_Beam',   ''),
                      array('torp_launchers',  'I1',           '',    'default' => '0',  'notnull'),
                      array('torp_launchers_normal',     'I1',           '',    'default' => '0',  'notnull'),  
                      array('torp_class',   'C',           '99',  'default' => 'Basic_Torpedo',   ''),
                      array('torps',           $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('shields',         'I1',           '',    'default' => '0',  'notnull'),
                      array('shields_normal',            'I1',           '',    'default' => '0',  'notnull'), 
                      array('shield_class',   'C',           '99',  'default' => 'Basic_Shield',   ''),
                      array('jammer',         'I1',           '',    'default' => '0',  'notnull'),
                      array('jammer_normal',            'I1',           '',    'default' => '0',  'notnull'), 
                      array('armour',          'I1',           '',    'default' => '0',  'notnull'),
                      array('armour_normal',             'I1',           '',    'default' => '0',  'notnull'), 
                      array('armor_class',   'C',           '99',  'default' => 'Basic_Armor',   ''),
                      array('armour_pts',      $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('cloak',           'I1',           '',    'default' => '0',  'notnull'),
                      array('cloak_normal',              'I1',           '',    'default' => '0',  'notnull'), 
                      array('fighters',        $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('owner',           'I',           '',    'default' => '0',  'notnull'),
                      array('team',            'I',           '',    'default' => '0',  'notnull'),
                      array('base',            'C',           '1',   'default' => 'N',  'notnull'),
                      array('team_cash',           'C',           '1',   'default' => 'Y',  'notnull'),
                      array('defeated',        'C',           '1',   'default' => 'N',  'notnull'),
                      array('prod_organics',   'I1',           '',    'default' => $default_prod_organics, 'notnull'),
                      array('prod_ore',        'I1',           '',    'default' => $default_prod_ore, 'notnull'),
                      array('prod_goods',      'I1',           '',    'default' => $default_prod_goods, 'notnull'),
                      array('prod_energy',     'I1',           '',    'default' => $default_prod_energy, 'notnull'),
                      array('prod_fighters',   'I1',           '',    'default' => $default_prod_fighters, 'notnull'),
                      array('prod_torp',       'I1',           '',    'default' => $default_prod_torp, 'notnull'),
                      array('prod_research',       'I1',           '',    'default' => $default_prod_research, 'notnull'),
                      array('prod_build',       'I1',           '',    'default' => $default_prod_build, 'notnull'),
                      array('cargo_hull',            'I',           '',    'default' => '0',  'notnull'),
                      array('cargo_power',            'I',           '',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['planets'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'owner',  'planets',  $dbtables['planets'],  'owner',  'planet_id');
    create_index($dict,  'team',   'planets',  $dbtables['planets'],  'team',   'planet_id');
    create_index($dict,  'base',   'planets',  $dbtables['planets'],  'base',   'planet_id');
    create_index($dict,  'sector_id',   'planets',  $dbtables['planets'],  'sector_id',   'planet_id');
    create_index($dict,  'defeated',   'planets',  $dbtables['planets'],  'defeated',   'planet_id');

    // End of planets table

    // Start players table
    echo "Creating table: players ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('player_id',        'I',           '',                '',  'auto',     'primary'),
                      array('currentship',      'I',           '',                'default' => '0',  'notnull'),
                      array('character_name',   'C',           '20',              '',                'notnull'),
                      array('email',            'C',           '60',              '',                'notnull'), 
                      array('credits',          'DECIMAL',  '32.0',                'default' => '0.0',  'notnull'),
                      array('turns',            'I',           '',                'default' => '0',  'notnull'),
                      array('turns_used',       'I',           '',                'default' => '0',  'notnull'),
                      array('last_login',       'T',   '',                '',                ''),
                      array('forum_login',       'T',   '',                '',                ''),
                      array('rating',           'I',           '',                'default' => '0',  'notnull'),
                      array('score',            'DECIMAL',           '24.0',                'default' => '0.0',  'notnull'),
                      array('team',             'I',           '',                'default' => '0',  'notnull'), 
                      array('team_invite',      'I',           '',                'default' => '0',  'notnull'), 
                      array('ip_address',       'C',           '16',              'default' => '0',  'notnull'),
                      array('trade_colonists',  'C',           '1',               'default' => 'Y',  'notnull'),
                      array('trade_fighters',   'C',           '1',               'default' => 'N',  'notnull'),
                      array('trade_torps',      'C',           '1',               'default' => 'N',  'notnull'),  
                      array('trade_energy',     'C',           '1',               'default' => 'Y',  'notnull'),
                      array('trade_ore',     'C',           '1',               'default' => 'N',  'notnull'),
                      array('trade_organics',     'C',           '1',               'default' => 'N',  'notnull'),
                      array('trade_goods',     'C',           '1',               'default' => 'N',  'notnull'),
                      array('password',         'C',           $maxlen_password,  '',    'notnull'),
                      array('last_team',          'I',           '',                'default' => '0',  'notnull'),
                      array('left_team_time',          'T',  '',    '',                ''),
                      array('team_join_count',          'I',           '',                'default' => '0',  'notnull'),
                      array('fed_bounty_count',            'DECIMAL',           '4.5',                'default' => '0.0',  'notnull'),
                      array('template',            'C',           '100',               '',  'notnull'),     
                      array('avatar',            'C',           '255',              '',                'notnull'), 
                      array('kills',       'I',           '',                'default' => '0',  'notnull'),
                      array('deaths',       'I',           '',                'default' => '0',  'notnull'),
                      array('captures',       'I',           '',                'default' => '0',  'notnull'),
                      array('planets_built',       'I',           '',                'default' => '0',  'notnull'),
                      array('planets_lost',       'I',           '',                'default' => '0',  'notnull'),
                      array('profile_name',            'C',           '250',              '',                'notnull'), 
                      array('profile_password',            'C',           '250',              '',                'notnull'), 
                      array('profile_id',       'I',           '',                'default' => '0',  'notnull'),
                      array('ship_losses',            'C',           '50',              '',                'notnull'), 
                      array('map_width',       'I',           '',                'default' => '50',  'notnull'),
                      array('experience',            'DECIMAL',           '24.2',                'default' => '0.0',  'notnull'),
                      array('npc',            'I4',           '',                'default' => '0',  'notnull'),
                      array('fed_attack_date',          'T',  '',    '',                'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['players'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict, 'currentship',  'players',  $dbtables['players'],  'currentship',  'player_id');
    create_index($dict, 'email',      'players',  $dbtables['players'],  'email',  'player_id');
    create_index($dict, 'team',       'players',  $dbtables['players'],  'team',  'player_id');
    create_index($dict, 'password',       'players',  $dbtables['players'],  'password',  'player_id');
    create_index($dict, 'score',       'players',  $dbtables['players'],  'score',  'player_id');
    create_index($dict, 'last_login',       'players',  $dbtables['players'],  'last_login',  'player_id');

    // End of players table

    // Start player team history table
    echo "Creating table: player team history ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('history_id',  'I',          '',    '',  'auto',  'primary'),
                      array('player_id',     'I',          '',    'default' => '0',  'notnull'),
                      array('history_team_id',      'I',          '',    'default' => '0',  'notnull'),
                      array('history_team_name',  'C',          '250',  '',                ''),
                      array('info',  'C',          '30',  '',                ''),
                      array('left_team',          'T',  '',    '',                ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['player_team_history'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'history_id',  'player_team_history',  $dbtables['player_team_history'],  'history_id',  'history_id');
    create_index($dict,  'player_id',  'player_team_history',  $dbtables['player_team_history'],  'player_id',  'history_id');
    create_index($dict,  'team_id',  'player_team_history',  $dbtables['player_team_history'],  'team_id',  'history_id');
    create_index($dict,  'left_team',  'player_team_history',  $dbtables['player_team_history'],  'left_team',  'history_id');
    // End player team history

    // Start player presets table
    echo "Creating table: presets ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('preset_id',        'I',           '',                '',  'auto',     'primary'),
                      array('player_id',     'I',          '',     'default' => '0',     ''),
                      array('preset',          'I',           '',                'default' => '0',  'notnull'),
                      array('info',  'C',          '15',  '',                ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['presets'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict, 'preset_id',  'presets',  $dbtables['presets'],  'preset_id',  'preset_id');
    create_index($dict, 'player_id',      'presets',  $dbtables['presets'],  'player_id',  'player_id');
    create_index($dict, 'preset',       'presets',  $dbtables['presets'],  'preset',  'preset_id');

    // End of players presets table

    // Start scan log table
    echo "Creating table: scan log ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('event_id',      'I',          '',     '',     'auto',  'primary'),
                      array('player_id',     'I',          '',     'default' => '0',     ''),
                      array('sector_id',     'I',          '',     'default' => '0',     'notnull'),
                      array('zone_id',  'I',          '',     'default' => '0',     ''),
                      array('time',          'T',  '',     '',                   ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['scan_log'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'player_id',  'scan_log',  $dbtables['scan_log'],  'player_id',  'event_id');
    create_index($dict,  'sector_id',  'scan_log',  $dbtables['scan_log'],  'sector_id',  'event_id');
    create_index($dict,  'zone_id',  'scan_log',  $dbtables['scan_log'],  'zone_id',  'event_id');
    create_index($dict,  'time',  'scan_log',  $dbtables['scan_log'],  'time',  'event_id');
    // End scan_log table

    // Start scheduler table
    echo "Creating table: scheduler ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('sched_id',    'I',          '',    '',     'auto',  'primary'),
                      array('loop',        'C',          '1',   'default' => 'N',     'notnull'),
                      array('ticks_left',  'I',          '',    'default' => '0',     'notnull'),
                      array('ticks_full',  'I',          '',    'default' => '0',     'notnull'),
                      array('spawn',       'I',          '',    'default' => '0',     'notnull'),
                      array('sched_file',  'C',          '30',  '',                   'notnull'),
                      array('extra_info',  'C',          '50',  '',                   'notnull'),
                      array('last_run',    'T',  '',    '',                   ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['scheduler'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'loop',  'scheduler',  $dbtables['scheduler'],  'loop',  'sched_id');
    create_index($dict,  'last_run',  'scheduler',  $dbtables['scheduler'],  'last_run',  'sched_id');
    create_index($dict,  'ticks_left',  'scheduler',  $dbtables['scheduler'],  'ticks_left',  'sched_id');
    create_index($dict,  'ticks_full',  'scheduler',  $dbtables['scheduler'],  'ticks_full',  'sched_id');
    // End scheduler table

    // Start sector defence table
    echo "Creating table: sector defences ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('defence_id',     'I',       '',    '',     'notnull',  'auto',  'primary'),
                      array('player_id',      'I',       '',    'default' => '0',     'notnull'),
                      array('sector_id',      'I',       '',    'default' => '0',     'notnull'),
                      array('defence_type',   'C',       '1',   'default' => 'M',     'notnull'),
                      array('firing_order',   'I',       '',    'default' => '0',     'notnull'),
                      array('damage_type',    'C',       '10',  'default' => 'A',     'notnull'),
                      array('weapon_class',    'C',       '99',  'default' => 'Basic',     'notnull'),
                      array('quantity',       $bigint_name,  '',  'default' => '0',     'notnull'),             
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['sector_defence'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'sector_id',  'sector_defence',  $dbtables['sector_defence'],  'sector_id',  'defence_id');
    create_index($dict,  'player_id',  'sector_defence',  $dbtables['sector_defence'],  'player_id',  'defence_id');
    create_index($dict,  'defence_type',  'sector_defence',  $dbtables['sector_defence'],  'defence_type',  'defence_id');

    // End of sector defence table

    // Start sessions table
    echo "Creating table: Sessions ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('sesskey',  'C',  '32',   'default' => '',   'notnull',  'primary'), 
                      array('expiry',   'I',  '',     'default' => '0',  'notnull'),             
                      array('expireref',   'C',  '64',     'default' => '0',  'notnull'),             
                      array('data',     'X',  '1024',  'default' => '',   'notnull'),             
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['sessions'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'expiry',  'sessions',  $dbtables['sessions'],  'expiry',  'sesskey');
    // End Sessions table

    // Start ship types table

    echo "Creating table: ship types ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('type_id',            'I',           '',     'default' => '1',  'notnull',  'primary'),
                      array('name',               'C',           '20',   '',   ''),
                      array('image',              'C',           '20',   '',   ''),
                      array('description',        'C',           '255',  '',   ''),              
                      array('buyable',            'C',           '1',    'default' => 'Y',  'notnull'),
                      array('cost_ore',           $bigint_name,  '',     'default' => '0',  'notnull'),
                      array('cost_goods',         $bigint_name,  '',     'default' => '0',  'notnull'),
                      array('cost_energy',        $bigint_name,  '',     'default' => '0',  'notnull'),
                      array('cost_organics',      $bigint_name,  '',     'default' => '0',  'notnull'),  
					  array('cost_tobuild',       $bigint_name,  '',     'default' => '0',  'notnull'),       
                      array('turnstobuild',       'I',           '',     'default' => '0',  'notnull'),
                      array('basehull',            'I',           '',     'default' => '0',  'notnull'), 
                      array('minhull',            'I',           '',     'default' => '0',  'notnull'), 
                      array('maxhull',            'I',           '',     'default' => '0',  'notnull'),
                      array('minengines',         'I',           '',     'default' => '0',  'notnull'),
                      array('maxengines',         'I',           '',     'default' => '0',  'notnull'),
                      array('minpower',           'I',           '',     'default' => '0',  'notnull'),
                      array('maxpower',           'I',           '',     'default' => '0',  'notnull'),
                      array('mincomputer',        'I',           '',     'default' => '0',  'notnull'), 
                      array('maxcomputer',        'I',           '',     'default' => '0',  'notnull'),
                      array('minsensors',         'I',           '',     'default' => '0',  'notnull'),
                      array('maxsensors',         'I',           '',     'default' => '0',  'notnull'),
                      array('minbeams',           'I',           '',     'default' => '0',  'notnull'),
                      array('maxbeams',           'I',           '',     'default' => '0',  'notnull'),
                      array('mintorp_launchers',  'I',           '',     'default' => '0',  'notnull'),
                      array('maxtorp_launchers',  'I',           '',     'default' => '0',  'notnull'),
                      array('minshields',         'I',           '',     'default' => '0',  'notnull'),
                      array('maxshields',         'I',           '',     'default' => '0',  'notnull'),
                      array('minarmour',          'I',           '',     'default' => '0',  'notnull'),
                      array('maxarmour',          'I',           '',     'default' => '0',  'notnull'),
                      array('mincloak',           'I',           '',     'default' => '0',  'notnull'),
                      array('maxcloak',           'I',           '',     'default' => '0',  'notnull'),
                      array('minecm',           'I',           '',     'default' => '0',  'notnull'),
                      array('maxecm',           'I',           '',     'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['ship_types'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End ship types table

    // Start ships table
    echo "Creating table: ships ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('ship_id',            'I',           '',    '',  'auto',  'primary'),
                      array('player_id',          'I',           '',    'default' => '0',  'notnull'),             
                      array('class',              'I',           '',    'default' => '1',  'notnull'),
                      array('name',               'C',           '50',  '',   ''), 
                      array('destroyed',          'C',           '1',   'default' => 'N',  'notnull'),
                      array('basehull',            'I1',           '',     'default' => '0',  'notnull'), 
                      array('hull',               'I1',           '',    'default' => '0',  'notnull'), 
                      array('hull_normal',               'I1',           '',    'default' => '0',  'notnull'), 
                      array('engines',            'I1',           '',    'default' => '0',  'notnull'), 
                      array('engines_normal',            'I1',           '',    'default' => '0',  'notnull'), 
                      array('power',              'I1',           '',    'default' => '0',  'notnull'), 
                      array('power_normal',              'I1',           '',    'default' => '0',  'notnull'), 
                      array('computer',           'I1',           '',    'default' => '0',  'notnull'), 
                      array('computer_normal',           'I1',           '',    'default' => '0',  'notnull'), 
                      array('computer_class',   'C',           '99',  'default' => 'Basic_Computer',   ''),
                      array('sensors',            'I1',           '',    'default' => '0',  'notnull'),          
                      array('sensors_normal',            'I1',           '',    'default' => '0',  'notnull'),          
                      array('beams',              'I1',           '',    'default' => '0',  'notnull'), 
                      array('beams_normal',              'I1',           '',    'default' => '0',  'notnull'), 
                      array('beam_class',   'C',           '99',  'default' => 'Basic_Beam',   ''),
                      array('torp_launchers',     'I1',           '',    'default' => '0',  'notnull'),  
                      array('torp_launchers_normal',     'I1',           '',    'default' => '0',  'notnull'),  
                      array('torp_class',   'C',           '99',  'default' => 'Basic_Torpedo',   ''),
                      array('torps',              $bigint_name,  '',    'default' => '0',  'notnull'), 
                      array('shields',            'I1',           '',    'default' => '0',  'notnull'), 
                      array('shields_normal',            'I1',           '',    'default' => '0',  'notnull'), 
                      array('shield_class',   'C',           '99',  'default' => 'Basic_Shield',   ''),
                      array('armour',             'I1',           '',    'default' => '0',  'notnull'), 
                      array('armour_normal',             'I1',           '',    'default' => '0',  'notnull'), 
                      array('armor_class',   'C',           '99',  'default' => 'Basic_Armor',   ''),
                      array('armour_pts',         $bigint_name,  '',    'default' => '0',  'notnull'), 
                      array('cloak',              'I1',           '',    'default' => '0',  'notnull'), 
                      array('cloak_normal',              'I1',           '',    'default' => '0',  'notnull'), 
                      array('ecm',              'I1',           '',    'default' => '0',  'notnull'), 
                      array('ecm_normal',              'I1',           '',    'default' => '0',  'notnull'), 
                      array('sector_id',          'I',           '',    'default' => '0',  'notnull'),  
                      array('ore',                $bigint_name,  '',    'default' => '0',  'notnull'), 
                      array('organics',           $bigint_name,  '',    'default' => '0',  'notnull'), 
                      array('goods',              $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('energy',             $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('colonists',          $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('fighters',           $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('on_planet',          'C',           '1',   'default' => 'N',  'notnull'),
                      array('dev_warpedit',       'I',           '',    'default' => '0',  'notnull'),
                      array('dev_beacon',        'I',           '',    'default' => '0',  'notnull'),
                      array('dev_genesis',        'I',           '',    'default' => '0',  'notnull'),
 					  array('dev_sectorgenesis',        'I',           '',    'default' => '0',  'notnull'),
                      array('dev_emerwarp',       'I',           '',    'default' => '0',  'notnull'),
                      array('dev_escapepod',      'C',           '1',   'default' => 'N',  'notnull'), 
                      array('dev_fuelscoop',      'C',           '1',   'default' => 'N',  'notnull'),
                      array('dev_nova',      'C',           '1',   'default' => 'N',  'notnull'),
                      array('dev_minedeflector',  $bigint_name,  '',    'default' => '0',  'notnull'),
                      array('planet_id',          'I',           '',    'default' => '0',  'notnull'),
                      array('cleared_defences',   'C',           '99',  'default' => '',   ''),
					  array('store_fee',   $bigint_name,           '',  'default' => '0',   'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['ships'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'sector_id',  'ships',  $dbtables['ships'],  'sector_id',  'ship_id');
    create_index($dict,  'player_id',  'ships',  $dbtables['ships'],  'player_id',  'ship_id');
    create_index($dict,  'planet_id',  'ships',  $dbtables['ships'],  'planet_id',  'ship_id');
    create_index($dict,  'destroyed',  'ships',  $dbtables['ships'],  'destroyed',  'ship_id');
    // End ships table

	 // Start probe table
    echo "Creating table: Probe ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('probe_id',            'I',           '',    '',  'auto',  'primary'),
                      array('owner_id',          'I',           '',    'default' => '0',  'notnull'),     
					  array('ship_id',          'I',           '',    'default' => '0',  'notnull'), 
                      array('engines',            'I',           '',    'default' => '0',  'notnull'), 
                      array('sensors',            'I',           '',    'default' => '0',  'notnull'),          
                      array('cloak',              'I',           '',    'default' => '0',  'notnull'), 
                      array('sector_id',          'I',           '',    'default' => '0',  'notnull'),  
                      array('type',                 'I',           '',    'default' => '0',  'notnull'),  
 					  array('active',                 'C',           '1',    'default' => 'N',  'notnull'),  
                      array('turns',                 'I',           '',    'default' => '0',  'notnull'),  
					  array('target_sector',                 'I',           '',    'default' => '0',  'notnull'),  
                      array('prev_sector',                 'I',           '',    'default' => '0',  'notnull'),
					  array('data',          'C',           '255',  '',                ''), );

    $sqlarray = $dict->CreateTableSQL($dbtables['probe'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'sector_id',  'probe',  $dbtables['probe'],  'sector_id',  'probe_id');
    create_index($dict,  'owner_id',  'probe',  $dbtables['probe'],  'owner_id',  'probe_id');
    create_index($dict,  'ship_id',  'probe',  $dbtables['probe'],  'ship_id',  'probe_id');
    create_index($dict,  'active',  'probe',  $dbtables['probe'],  'active',  'probe_id');
    // End probe table

	
    // Start Message Block table
    echo "Creating table: Message Block ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('mb_id',        $bigint_name,  '',     '',  'auto',  'primary'), 
                      array('blocked_player_id',      'I',           '',     'default' => '0',  'notnull'),
					  array('player_id',          'I',           '',    'default' => '0',  'notnull'),  
                     );  

    $sqlarray = $dict->CreateTableSQL($dbtables['message_block'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'blocked_player_id',  'blocked_player_id',  $dbtables['message_block'],  'blocked_player_id',  'mb_id');
    create_index($dict,  'player_id',  'player_id',  $dbtables['message_block'],  'player_id',  'mb_id');
    // End Message Block table

	
	echo "Creating table: Shoutbox ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('sb_id',       $bigint_name,  '',           '',       'auto',  'primary'),
                      array('player_id',       $bigint_name,           '',          'default' => '0',       'notnull'),   
                      array('player_name',     'C',           '60',           'default' => '',       'notnull'),   
                      array('sb_date',    $bigint_name,           '',           'default' => '0',       'notnull'),   
                      array('sb_text',      'X',           '',           'default' => '',       'notnull'),   
                      array('sb_alli',       $bigint_name,           '',           'default' => '',       'notnull'),            
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['shoutbox'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'sb_date',  'shoutbox',  $dbtables['shoutbox'],  'sb_date',  'sb_id');
    create_index($dict,  'sb_alli',  'shoutbox',  $dbtables['shoutbox'],  'sb_alli',  'sb_id');

    // Start spies table
    echo "Creating table: Spies ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('spy_id',       $bigint_name,  '',           '',       'auto',  'primary'),
                      array('active',       'C',           '1',          'default' => 'N',       'notnull'),   
                      array('owner_id',     'I',           '',           'default' => '0',       'notnull'),   
                      array('planet_id',    'I',           '',           'default' => '0',       'notnull'),   
                      array('ship_id',      'I',           '',           'default' => '0',       'notnull'),   
                      array('job_id',       'I',           '',           'default' => '0',       'notnull'),            
                      array('spy_percent',  'DECIMAL',       $float_size,  'default' => '0.0',     'notnull'),   
                      array('move_type',    'C',           '10',         'default' => 'toship',  'notnull'),    
                      array('try_sabot',    'C',           '1',          'default' => 'Y',       'notnull'),
                      array('try_inter',    'C',           '1',          'default' => 'Y',       'notnull'),
                      array('try_birth',    'C',           '1',          'default' => 'Y',       'notnull'),
                      array('try_steal',    'C',           '1',          'default' => 'Y',       'notnull'),
                      array('try_torps',    'C',           '1',          'default' => 'Y',       'notnull'),
                      array('try_fits',     'C',           '1',          'default' => 'Y',       'notnull'),
                      array('try_capture',  'C',           '1',          'default' => 'Y',       'notnull'),
                      array('spy_cloak',       'I1',           '',           'default' => '0',       'notnull'),            
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['spies'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'planet_id',  'spies',  $dbtables['spies'],  'planet_id',  'spy_id');
    create_index($dict,  'owner_id',   'spies',  $dbtables['spies'],  'owner_id',   'spy_id');
    create_index($dict,  'active',    'spies',  $dbtables['spies'],  'active',    'spy_id');
    create_index($dict,  'ship_id',    'spies',  $dbtables['spies'],  'ship_id',    'spy_id');
    create_index($dict,  'job_id',    'spies',  $dbtables['spies'],  'job_id',    'spy_id');
    // End Spy table

    // Start teams table
    echo "Creating table: teams ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('id',                 'I',  '',    '',  'auto',     'primary'),
                      array('creator',            'I',  '',    'default' => '0',  'notnull'),
                      array('team_name',          'C',  '40',  '',                ''),
                      array('description',        'C',  '150',  '',                ''),
                      array('icon',        'C',  '255',  '',                ''),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['teams'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'creator',  'teams',  $dbtables['teams'],  'creator',  'id');

    // End of teams table

    // Start of traderoutes table
    echo "Creating table: traderoutes ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('traderoute_id',  'I',  '',   '',  'auto',     'primary'),
                      array('source_id',      'I',  '',   'default' => '0',  'notnull'),
                      array('dest_id',        'I',  '',   'default' => '0',  'notnull'),
                      array('source_type',    'C',  '1',  'default' => 'P',  'notnull'),
                      array('dest_type',      'C',  '1',  'default' => 'P',  'notnull'),
                      array('move_type',      'C',  '1',  'default' => 'W',  'notnull'),
                      array('owner',          'I',  '',   'default' => '0',  'notnull'),
                      array('circuit',        'C',  '1',  'default' => '2',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['traderoutes'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'owner',  'traderoutes',  $dbtables['traderoutes'],  'owner',  'traderoute_id');
    create_index($dict,  'source_type',  'traderoutes',  $dbtables['traderoutes'],  'source_type',  'traderoute_id');
    create_index($dict,  'move_type',  'traderoutes',  $dbtables['traderoutes'],  'move_type',  'traderoute_id');
    create_index($dict,  'dest_type',  'traderoutes',  $dbtables['traderoutes'],  'dest_type',  'traderoute_id');
    create_index($dict,  'source_id',  'traderoutes',  $dbtables['traderoutes'],  'source_id',  'traderoute_id');
    create_index($dict,  'dest_id',  'traderoutes',  $dbtables['traderoutes'],  'dest_id',  'traderoute_id');
    create_index($dict,  'circuit',  'traderoutes',  $dbtables['traderoutes'],  'circuit',  'traderoute_id');

    // End of traderoutes table

    // Start universe table
    echo "Creating table: universe ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('sector_id',      $bigint_name,           '',    '',     'auto',     'primary'),
                      array('sector_name',    'C',           '30',  '',                   'notnull'),
                      array('zone_id',        'I',           '',    'default' => '0',     'notnull'),
                      array('star_size',      'I',           '',    'default' => '0',     'notnull'),    
                      array('port_type',      'C',           '10',  'default' => 'none',  'notnull'), 
                      array('port_organics',  $bigint_name,  '',    'default' => '0',     'notnull'), 
                      array('port_ore',       $bigint_name,  '',    'default' => '0',     'notnull'), 
                      array('port_goods',     $bigint_name,  '',    'default' => '0',     'notnull'), 
                      array('port_energy',    $bigint_name,  '',    'default' => '0',     'notnull'),
                      array('organics_price',      'DECIMAL',           '11.10',    'default' => '0.0',     'notnull'),    
                      array('ore_price',      'DECIMAL',           '11.10',    'default' => '0.0',     'notnull'),    
                      array('goods_price',      'DECIMAL',           '11.10',    'default' => '0.0',     'notnull'),    
                      array('energy_price',      'DECIMAL',           '11.10',    'default' => '0.0',     'notnull'),    
                      array('fixed_organics_price',      'I',           '',    'default' => '0',     'notnull'),    
                      array('fixed_ore_price',      'I',           '',    'default' => '0',     'notnull'),    
                      array('fixed_goods_price',      'I',           '',    'default' => '0',     'notnull'),    
                      array('fixed_energy_price',      'I',           '',    'default' => '0',     'notnull'),    
                      array('trade_date',       'T',  '',    '',                'notnull'),
                      array('fixed_price',      'I',           '',    'default' => '0',     'notnull'),    
                      array('x',              'I',           '',    'default' => '0',     'notnull'),
                      array('y',              'I',           '',    'default' => '0',     'notnull'),
                      array('z',              'I',           '',    'default' => '0',     'notnull'),
                      array('spiral_arm',              'I',           '',    'default' => '0',     'notnull'),
                      array('beacon',         'C',           '50',  '',                   'notnull'),
                      array('sg_sector',              'I1',           '',    'default' => '0',  'notnull'), 
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['universe'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'port_type',  'universe',  $dbtables['universe'],  'port_type',  'sector_id');
    create_index($dict,  'zone_id',    'universe',  $dbtables['universe'],  'zone_id',  'sector_id');
    create_index($dict,  'trade_date',    'universe',  $dbtables['universe'],  'trade_date',  'sector_id');
    create_index($dict,  'port_organics',    'universe',  $dbtables['universe'],  'port_organics',  'sector_id');
    create_index($dict,  'port_ore',    'universe',  $dbtables['universe'],  'port_ore',  'sector_id');
    create_index($dict,  'port_goods',    'universe',  $dbtables['universe'],  'port_goods',  'sector_id');
    create_index($dict,  'energy_price',    'universe',  $dbtables['universe'],  'energy_price',  'sector_id');
    create_index($dict,  'x',    'universe',  $dbtables['universe'],  'x',  'sector_id');
    create_index($dict,  'y',    'universe',  $dbtables['universe'],  'y',  'sector_id');
    create_index($dict,  'z',    'universe',  $dbtables['universe'],  'z',  'sector_id');

    // End of universe table

    // Start navmap table
    echo "Creating table: navmap ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('nav_id',      $bigint_name,           '',    '',     'auto',     'primary'),
                      array('start_sector',              'I',           '',    'default' => '0',     'notnull'),
                      array('dest_sector',              'I',           '',    'default' => '0',     'notnull'),
                      array('distance',              'I',           '',    'default' => '0',     'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['navmap'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'start_sector',  'navmap',  $dbtables['navmap'],  'start_sector',  'nav_id');


    // End of navmap table

    // Start zones table
    echo "Creating table: zones ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('zone_id',             'I',  '',    '',  'auto',     'primary'),
                      array('zone_name',           'C',  '40',  '',                ''),
                      array('owner',               'I',  '',    'default' => '0',  'notnull'),
                      array('team_zone',           'C',  '1',   'default' => 'N',  'notnull'),
                      array('allow_beacon',        'C',  '1',   'default' => 'Y',  'notnull'),
                      array('allow_attack',        'C',  '1',   'default' => 'Y',  'notnull'),
                      array('allow_planetattack',  'C',  '1',   'default' => 'Y',  'notnull'),
                      array('allow_warpedit',      'C',  '1',   'default' => 'Y',  'notnull'),
                      array('allow_planet',        'C',  '1',   'default' => 'Y',  'notnull'),
                      array('allow_trade',         'C',  '1',   'default' => 'Y',  'notnull'),
                      array('allow_defenses',      'C',  '1',   'default' => 'Y',  'notnull'),
                      array('max_hull',            'I',  '',    'default' => '0',  'notnull'),
                      array('zone_color',      'C',  '8',   'default' => '#000000',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['zones'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);

	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'owner',  'zones',  $dbtables['zones'],  'owner',  'zone_id');
    create_index($dict,  'team_zone',  'zones',  $dbtables['zones'],  'team_zone',  'zone_id');
    // End of zones table

	// Start of Team Forum Tables
	
    // Start forums table
    echo "Creating table: forums ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('forum_id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('forum_name',  'C',  '150',     'default' => '0',  'notnull'),
                      array('forum_desc',    'X',  '',     '',  'notnull'),
                      array('forum_posts',    'I',  '',  'default' => '0',   'notnull'),
                      array('forum_topics',    'I',  '',  'default' => '0',   'notnull'),
                      array('lastposttime',    'T',  '',     '',                'notnull'), 
                      array('private',   'I',  '',    'default' => '0',  'notnull'),
                      array('teams',   'I',  '',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['forums'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End forums table

    // Start fplayers table
    echo "Creating table: fplayers ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('rec_id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('player_id',  'I',  '',     'default' => '0',  'notnull'),
                      array('playername',    'C',  '250',     'default' => '0',  'notnull'),
                      array('signupdate',    'T',  '',  '',   'notnull'),
                      array('lastonline',    'T',  '',  '',   'notnull'),
                      array('currenttime',    'T',  '',     '',                'notnull'), 
                      array('postcount',   'I',  '',    'default' => '0',  'notnull'),
                      array('admin',   'I',  '',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['fplayers'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End fplayers table

    // Start posts table
    echo "Creating table: posts ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('post_id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('topic_id',  'I',  '',     'default' => '0',  'notnull'),
                      array('forum_id',  'I',  '',     'default' => '0',  'notnull'),
                      array('post_time',    'T',  '',  '',   'notnull'),
                      array('post_edit_time',    'T',  '',  '',   'notnull'),
                      array('post_edit_count',    'I',  '',     'default' => '0',                'notnull'), 
                      array('post_username',   'C',  '250',    'default' => '0',  'notnull'),
                      array('post_player_id',   'I',  '',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['posts'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End posts table

    // Start posts_text table
    echo "Creating table: posts_text ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('post_id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('post_text',    'X',  '',     '',  'notnull'),
                      array('topic_id',    'I',  '',  'default' => '0',   'notnull'),
                      array('forum_id',    'I',  '',  'default' => '0',   'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['posts_text'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End posts_text table

    // Start topics table
    echo "Creating table: topics ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('topic_id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('topic_title',   'C',  '60',    'default' => '0',  'notnull'),
                      array('topic_poster',   'C',  '250',    'default' => '0',  'notnull'),
                      array('topic_time',    'T',  '',  '',   'notnull'),
                      array('lastpostdate',    'T',  '',  '',   'notnull'),
                      array('topic_views',   'I',  '',    'default' => '0',  'notnull'),
                      array('topic_replies',   'I',  '',    'default' => '0',  'notnull'),
                      array('forum_id',   'I',  '',    'default' => '0',  'notnull'),
                      array('topic_status',   'I',  '',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['topics'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End topics table

    // Start word censor table
    echo "Creating table: wordcensor ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('name',   'C',  '50',    'default' => '0',  'notnull'),
                      array('value',   'C',  '50',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['wordcensor'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'name',  'name',  $dbtables['wordcensor'],  'name',  'id');
    // End wordcensor table
	
    // Start sector_notes table
    echo "Creating table: sector_notes ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('note_id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('note_player_id',    'I',  '',  'default' => '0',   'notnull'),
                      array('note_team_id',    'I',  '',  'default' => '0',   'notnull'),
                      array('note_sector_id',    'I',  '',  'default' => '0',   'notnull'),
                      array('note_data',    'X',  '',     '',  'notnull'),
                      array('note_date',    'T',  '',  '',   'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['sector_notes'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
 	//					keyname1		keyname2	tablename			indexfield		primary
    create_index($dict,  'note_player_id',  'note_player_id',  $dbtables['sector_notes'],  'note_player_id',  'note_id');
    create_index($dict,  'note_team_id',  'note_team_id',  $dbtables['sector_notes'],  'note_team_id',  'note_id');
    create_index($dict,  'note_date',  'note_date',  $dbtables['sector_notes'],  'note_date',  'note_id');
    create_index($dict,  'note_sector_id',  'note_sector_id',  $dbtables['sector_notes'],  'note_sector_id',  'note_id');
   // End posts_text table

	// Start of Casino Forum Tables
	
    // Start forums table
    echo "Creating table: casino_forums ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('forum_id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('forum_name',  'C',  '150',     'default' => '0',  'notnull'),
                      array('forum_desc',    'X',  '',     '',  'notnull'),
                      array('forum_posts',    'I',  '',  'default' => '0',   'notnull'),
                      array('forum_topics',    'I',  '',  'default' => '0',   'notnull'),
                      array('lastposttime',    'T',  '',     '',                'notnull'), 
                      array('private',   'I',  '',    'default' => '0',  'notnull'),
                      array('casino_sector',   'I',  '',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['casino_forums'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End forums table

    // Start posts table
    echo "Creating table: casino_posts ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('post_id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('topic_id',  'I',  '',     'default' => '0',  'notnull'),
                      array('forum_id',  'I',  '',     'default' => '0',  'notnull'),
                      array('post_time',    'T',  '',  '',   'notnull'),
                      array('post_edit_time',    'T',  '',  '',   'notnull'),
                      array('post_edit_count',    'I',  '',     'default' => '0',                'notnull'), 
                      array('post_username',   'C',  '250',    'default' => '0',  'notnull'),
                      array('post_player_id',   'I',  '',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['casino_posts'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End posts table

    // Start posts_text table
    echo "Creating table: casino_posts_text ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('post_id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('post_text',    'X',  '',     '',  'notnull'),
                      array('topic_id',    'I',  '',  'default' => '0',   'notnull'),
                      array('forum_id',    'I',  '',  'default' => '0',   'notnull'),
                      array('post_player_id',   'I',  '',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['casino_posts_text'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End posts_text table

    // Start topics table
    echo "Creating table: casino_topics ";
    $dict = NewDataDictionary($db); 
    $fldarray = array(
                      array('topic_id',         'I',  '',     '',  'notnull',  'auto',     'primary'),
                      array('topic_title',   'C',  '60',    'default' => '0',  'notnull'),
                      array('topic_poster',   'C',  '250',    'default' => '0',  'notnull'),
                      array('topic_time',    'T',  '',  '',   'notnull'),
                      array('lastpostdate',    'T',  '',  '',   'notnull'),
                      array('topic_views',   'I',  '',    'default' => '0',  'notnull'),
                      array('topic_replies',   'I',  '',    'default' => '0',  'notnull'),
                      array('forum_id',   'I',  '',    'default' => '0',  'notnull'),
                      array('topic_status',   'I',  '',    'default' => '0',  'notnull'),
                      array('post_player_id',   'I',  '',    'default' => '0',  'notnull'),
                     );

    $sqlarray = $dict->CreateTableSQL($dbtables['casino_topics'], $fldarray, $taboptarray);
    $debug_query = $dict->ExecuteSQLArray($sqlarray);
    db_op_result($debug_query,__LINE__,__FILE__);
    // End topics table

    //Finished
    $debug_query = '';
    if ($cumulative == 0)
    {
        echo "<b>All tables created successfully.</b><p>";
    }
    else
    {
        echo "<b><font color=\"yellow\">At least one error occured during table creation.</font></b><br>\n";
    }
}

?>
